@@ -285,7 +285,7 @@ class Auth
             "autologin"  => $autologin
         );
         $cookie = base64_encode(serialize($cookie));
-        setcookie($cookie_name, $cookie, APP_COOKIE_EXPIRE, APP_RELATIVE_URL);
+        setcookie($cookie_name, $cookie, APP_COOKIE_EXPIRE, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
     }
 
 
@@ -335,7 +335,7 @@ class Auth
      */
     function removeCookie($cookie_name)
     {
-        setcookie($cookie_name, "", time()-36000, APP_RELATIVE_URL);
+        setcookie($cookie_name, "", time()-36000, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
     }
 
 
@@ -392,7 +392,7 @@ class Auth
             Error_Handler::logError(array($passwd->getMessage(), $passwd->getDebugInfo()), __FILE__, __LINE__);
             return false;
         } else {
-            if ($passwd != md5($password)) {
+            if ($passwd != Auth::hashPassword($password)) {
                 return false;
             } else {
                 return true;
@@ -483,17 +483,15 @@ class Auth
      * @param   integer $remember Whether to automatically remember the setting or not
      * @return  void
      */
-    function setCurrentProject($project, $remember, $auto_switched = false)
+    function setCurrentProject($project, $remember)
     {
         $cookie = array(
             "prj_id"   => $project,
             "remember" => $remember
         );
-        if ($auto_switched == true) {
-            $cookie['auto_switched_from'] = Auth::getCurrentProject();
-        }
         $cookie = base64_encode(serialize($cookie));
-        setcookie(APP_PROJECT_COOKIE, $cookie, APP_PROJECT_COOKIE_EXPIRE, APP_RELATIVE_URL);
+        setcookie(APP_PROJECT_COOKIE, $cookie, APP_PROJECT_COOKIE_EXPIRE, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
+        Auth::createFakeCookie(Auth::getUserID(), $project);
     }
 
 
@@ -526,6 +524,24 @@ class Auth
         }
         $HTTP_COOKIE_VARS[APP_PROJECT_COOKIE] = base64_encode(serialize($cookie));
     }
+
+
+    /**
+     * Hashes the password according to APP_HASH_TYPE constant
+     *
+     * @access  public
+     * @param   string $password The plain text password
+     * @return  string The hashed password
+     */
+    function hashPassword($password)
+    {
+        if (APP_HASH_TYPE == 'MD5-64') {
+            return base64_encode(pack('H*',md5($password)));
+        } else {
+            // default to md5
+            return md5($password);
+        }
+    }
 }
 
 // benchmarking the included file (aka setup time)
