@@ -22,7 +22,7 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: João Prado Maia <jpm@mysql.com>                             |
+// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
 //
@@ -41,7 +41,7 @@ include_once(APP_INC_PATH . "class.reminder.php");
  * different platforms.
  *
  * @version 1.0
- * @author João Prado Maia <jpm@mysql.com>
+ * @author Joo Prado Maia <jpm@mysql.com>
  */
 
 class Mail_API
@@ -334,6 +334,7 @@ class Mail_API
     function getSMTPSettings()
     {
         $settings = Setup::load();
+        settype($settings['smtp']['auth'], 'boolean');
         return $settings["smtp"];
     }
 
@@ -748,6 +749,8 @@ class Mail_API
                     $new_headers['X-Eventum-Level'] = $support_levels[Customer::getSupportLevelID($prj_id, $customer_id)];
                 }
             }
+            $new_headers['X-Eventum-Category'] = Category::getTitle(Issue::getCategory($issue_id));
+            $new_headers['X-Eventum-Project'] = Project::getName($prj_id);
         }
         $new_headers['X-Eventum-Type'] = $type;
         return $new_headers;
@@ -783,10 +786,10 @@ class Mail_API
     function getReferenceMessageID($text_headers)
     {
         $references = array();
-        if (preg_match('/^In-Reply-To: (.*)/m', $text_headers, $matches)) {
+        if (preg_match('/^In-Reply-To: (.*)/mi', $text_headers, $matches)) {
             return trim($matches[1]);
         }
-        if (preg_match('/^References: (.+?)(\r?\n\r?\n|\r?\n\r?\S)/sm', $text_headers, $matches)) {
+        if (preg_match('/^References: (.+?)(\r?\n\r?\n|\r?\n\r?\S)/smi', $text_headers, $matches)) {
             $references = explode(" ", Mail_API::unfold(trim($matches[1])));
             $references = array_map('trim', $references);
             // return the first message-id in the list of references
@@ -806,14 +809,19 @@ class Mail_API
     function getAllReferences($text_headers)
     {
         $references = array();
-        if (preg_match('/^In-Reply-To: (.*)/m', $text_headers, $matches)) {
+        if (preg_match('/^In-Reply-To: (.*)/mi', $text_headers, $matches)) {
             $references[] = trim($matches[1]);
         }
-        if (preg_match('/^References: (.+?)(\r?\n\r?\n|\r?\n\r?\S)/sm', $text_headers, $matches)) {
+        if (preg_match('/^References: (.+?)(\r?\n\r?\n|\r?\n\r?\S)/smi', $text_headers, $matches)) {
             $references = array_merge($references, explode(" ", Mail_API::unfold(trim($matches[1]))));
             $references = array_map('trim', $references);
             $references = array_unique($references);
         }
+        foreach ($references as $key => $reference) {
+            if (empty($reference)) {
+                unset($references[$key]);
+            }
+        }
         return $references;
     }
 
@@ -855,20 +863,20 @@ class Mail_API
             $headers['message-id'] = $msg_id;
         }
 
-        if (preg_match('/^In-Reply-To: (.*)/m', $text_headers) > 0) {
+        if (preg_match('/^In-Reply-To: (.*)/mi', $text_headers) > 0) {
             // replace existing header
-            $text_headers = preg_replace('/^In-Reply-To: (.*)/m', 'In-Reply-To: ' . $reference_msg_id, $text_headers, 1);
+            $text_headers = preg_replace('/^In-Reply-To: (.*)/mi', 'In-Reply-To: ' . $reference_msg_id, $text_headers, 1);
         } else {
             // add new header after message ID
-            $text_headers = preg_replace('/^Message-ID: (.*)$/m', "Message-ID: $1\r\nIn-Reply-To: $reference_msg_id", $text_headers, 1);
+            $text_headers = preg_replace('/^Message-ID: (.*)$/mi', "Message-ID: $1\r\nIn-Reply-To: $reference_msg_id", $text_headers, 1);
         }
         $headers['in-reply-to'] = $reference_msg_id;
-        if (preg_match('/^References: (.*)/m', $text_headers) > 0) {
+        if (preg_match('/^References: (.*)/mi', $text_headers) > 0) {
             // replace existing header
-            $text_headers = preg_replace('/^References: (.*)/m', 'References: ' . Mail_API::fold(join(' ', $references)), $text_headers, 1);
+            $text_headers = preg_replace('/^References: (.*)/mi', 'References: ' . Mail_API::fold(join(' ', $references)), $text_headers, 1);
         } else {
             // add new header after In-Reply-To
-            $text_headers = preg_replace('/^In-Reply-To: (.*)$/m', "In-Reply-To: $1\r\nReferences: " . Mail_API::fold(join(' ', $references)), $text_headers, 1);
+            $text_headers = preg_replace('/^In-Reply-To: (.*)$/mi', "In-Reply-To: $1\r\nReferences: " . Mail_API::fold(join(' ', $references)), $text_headers, 1);
         }
         $headers['references'] = Mail_API::fold(join(' ', $references));
         return array($text_headers . "\r\n\r\n" . $body, $headers);
@@ -968,11 +976,10 @@ class Mail_API
     function getMessageID($headers, $body)
     {
         // try to parse out actual message-id header
-        if (preg_match('/^Message-ID: (.*)/m', $headers, $matches)) {
+        if (preg_match('/^Message-ID: (.*)/mi', $headers, $matches)) {
             return trim($matches[1]);
         } else {
             // no match, calculate hash to make fake message ID
-            $md5 = md5($headers.$body);
             $first = base_convert(md5($headers), 10, 36);
             $second = base_convert(md5($body), 10, 36);
             return "<eventum.md5." . $first . "." . $second . "@" . APP_HOSTNAME . ">";
