@@ -267,14 +267,15 @@ class Workflow
      * @param   integer $issue_id The ID of the issue.
      * @param   object $message An object containing the new email
      * @param   array $row The array of data that was inserted into the database.
+     * @param   boolean $closing If we are closing the issue.
      */
-    function handleNewEmail($prj_id, $issue_id, $message, $row = FALSE)
+    function handleNewEmail($prj_id, $issue_id, $message, $row = FALSE, $closing = false)
     {
         if (!Workflow::hasWorkflowIntegration($prj_id)) {
             return;
         }
         $backend =& Workflow::_getBackend($prj_id);
-        return $backend->handleNewEmail($prj_id, $issue_id, $message, $row);
+        return $backend->handleNewEmail($prj_id, $issue_id, $message, $row, $closing);
     }
 
 
@@ -443,6 +444,44 @@ class Workflow
         $backend =& Workflow::_getBackend($prj_id);
         return $backend->getAdditionalEmailAddresses($prj_id, $issue_id, $event);
     }
+
+
+    /**
+     * Indicates if the the specified email address can email the issue. Can be
+     * used to disable email blocking by always returning true.
+     *
+     * @param   integer $prj_id The project ID.
+     * @param   integer $issue_id The ID of the issue
+     * @param   string The email address that is trying to send an email
+     * @return  boolean true if the sender can email the issue, false if the sender
+     *          should not email the issue and null if the default rules should be used.
+     */
+    function canEmailIssue($prj_id, $issue_id, $email)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return null;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->canEmailIssue($prj_id, $issue_id, $email);
+    }
+
+
+    /**
+     * Handles when an authorized replier is added
+     *
+     * @param   integer $prj_id The project ID
+     * @param   integer $issue_id The ID of the issue
+     * @param   string  $email The email address added
+     * @return  boolean
+     */
+    function handleAuthorizedReplierAdded($prj_id, $issue_id, &$email)
+    {
+        if (!Workflow::hasWorkflowIntegration($prj_id)) {
+            return null;
+        }
+        $backend =& Workflow::_getBackend($prj_id);
+        return $backend->handleAuthorizedReplierAdded($prj_id, $issue_id, $email);
+    }
 }
 
 
